@@ -1,6 +1,6 @@
 import requests
 BASE = "http://api.choir.io/"
-VERSION = "0.2"
+VERSION = "0.3"
 
 
 EMO_E = ["g", "n", "b"]
@@ -20,7 +20,9 @@ class Choir:
 
     def emote(self, emo, intr, label, text=None, sprinkle=None, tag=None):
         """
-            Uses Choir's flexible sound specification. Raises ChoirError on error.
+            Uses Choir's flexible sound specification. Raises ChoirError in case
+            of parameter errors. Returns True of message was succesfully sent,
+            False otherwise.
         """
         emo = emo.lower()
         if not emo in EMO_E:
@@ -35,7 +37,9 @@ class Choir:
 
     def say(self, pack, name, label, text=None, sprinkle=None):
         """
-            Uses Choir's direct sound specification. Raises ChoirError on error.
+            Uses Choir's direct sound specification. Raises ChoirError in case
+            of parameter errors. Returns True of message was succesfully sent,
+            False otherwise.
         """
         return self._send("%s/%s"%(pack, name), label, text, sprinkle)
 
@@ -49,6 +53,7 @@ class Choir:
         try:
             resp = requests.post(self.base, data=data)
         except requests.ConnectionError, v:
-            raise ChoirError("Could not connect")
+            return False
         if resp.status_code != 200:
-            raise ChoirError("Feed error: %s", resp.content)
+            return False
+        return True
